package com.care.bms.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.care.bms.service.CareEventOrderService;
import com.care.common.entity.CareEventOrder;
import com.care.common.enums.OrderStatusEnum;
import com.care.common.enums.OrderTypeEnum;
import com.care.common.mapper.CareEventOrderMapper;
import com.care.common.vo.PageReqVO;
import com.care.common.vo.UserLogindConvertVO;
import com.care.common.vo.event.CareEventOrderVO;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 事件定单表(CareEventOrder)表服务实现类
 *
 * @author makejava
 * @since 2021-05-21 00:08:29
 */
@Service
public class CareEventOrderServiceImpl extends ServiceImpl<CareEventOrderMapper, CareEventOrder> implements CareEventOrderService {

    /**
     * 工单查询
     * @param orderStatus
     * @param olderName
     * @param loginUser
     * @param pageReqVo
     * @return
     */
    @Override
    public IPage<CareEventOrderVO> listEvent(String orderStatus, String olderName, UserLogindConvertVO loginUser, PageReqVO pageReqVo) {
        IPage<CareEventOrder> page = new Page<>(pageReqVo.getCurrent(), pageReqVo.getPageSize());
        QueryWrapper<CareEventOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(StrUtil.isNotEmpty(orderStatus),CareEventOrder::getStatus, orderStatus)
                .like(StrUtil.isNotEmpty(olderName),CareEventOrder::getOlderName,olderName)
                .eq(CareEventOrder::getOrgId,loginUser.getOrgId())
                .eq(loginUser.getStationId()!=null,CareEventOrder::getStationId,loginUser.getStationId())
                .orderByAsc(CareEventOrder::getCreateTime);
        /*if ("asc".equalsIgnoreCase(pageReqVo.getOrderBy())){
            queryWrapper.lambda().orderByAsc(pageReqVo.getOrderField()!=null,pageReqVo.getOrderField());
        }else{
            queryWrapper.orderByDesc(pageReqVo.getOrderField()!=null,pageReqVo.getOrderField());
        }*/


        IPage<CareEventOrder> pageRes = this.page(page, queryWrapper);
        IPage<CareEventOrderVO> results = new Page<>(pageRes.getCurrent(),pageRes.getSize(),pageRes.getTotal());
        if(CollUtil.isNotEmpty(pageRes.getRecords())){
            List<CareEventOrderVO> list = new ArrayList<>();
            pageRes.getRecords().forEach(item -> {
                CareEventOrderVO  resVO = new CareEventOrderVO();
                BeanUtils.copyProperties(item,resVO);
                resVO.setOrderTypeName(OrderTypeEnum.getCodeToName(item.getOrderType()));
                resVO.setStatusName(OrderStatusEnum.getCodeToName(item.getStatus()));
                list.add(resVO);
            });
            results.setRecords(list);
        }
        return results;
    }

    /**
     * 我的处理事件 - 坐席
     *
     * @param orderStatus
     * @param olderName
     * @param loginUser
     * @param pageReqVo
     * @return
     */
    @Override
    public IPage<CareEventOrderVO> listEvent4MyDo(String orderStatus, String olderName, UserLogindConvertVO loginUser, PageReqVO pageReqVo) {
        IPage<CareEventOrder> page = new Page<>(pageReqVo.getCurrent(), pageReqVo.getPageSize());
        QueryWrapper<CareEventOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(StrUtil.isNotEmpty(orderStatus),CareEventOrder::getStatus, orderStatus)
                .like(StrUtil.isNotEmpty(olderName),CareEventOrder::getOlderName,olderName)
                .eq(CareEventOrder::getOrgId,loginUser.getOrgId())
                .eq(CareEventOrder::getSeatId,loginUser.getId())
                .orderByAsc(CareEventOrder::getModifyTime);;
       /* if ("asc".equalsIgnoreCase(pageReqVo.getOrderBy())){
            queryWrapper.orderByAsc(pageReqVo.getOrderField()!=null,pageReqVo.getOrderField());
        }else{
            queryWrapper.orderByDesc(pageReqVo.getOrderField()!=null,pageReqVo.getOrderField());
        }*/
        IPage<CareEventOrder> pageRes = this.page(page, queryWrapper);
        IPage<CareEventOrderVO> results = new Page<>(pageRes.getCurrent(),pageRes.getSize(),pageRes.getTotal());
        if(CollUtil.isNotEmpty(pageRes.getRecords())){
            List<CareEventOrderVO> list = new ArrayList<>();
            pageRes.getRecords().forEach(item -> {
                CareEventOrderVO  resVO = new CareEventOrderVO();
                BeanUtils.copyProperties(item,resVO);
                resVO.setOrderTypeName(OrderTypeEnum.getCodeToName(item.getOrderType()));
                resVO.setStatusName(OrderStatusEnum.getCodeToName(item.getStatus()));
                list.add(resVO);
            });
            results.setRecords(list);
        }
        return results;
    }
}